/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.callback.util;

import org.apache.hudi.exception.HoodieCommitCallbackException;

import com.fasterxml.jackson.databind.ObjectMapper;

import java.io.IOException;

/**
 * Util helps to prepare callback message.
 */
public class HoodieWriteCommitCallbackUtil {

  private static final ObjectMapper MAPPER = new ObjectMapper();

  /**
   * Convert data to json string format.
   */
  public static String convertToJsonString(Object obj) {
    try {
      return MAPPER.writeValueAsString(obj);
    } catch (IOException e) {
      throw new HoodieCommitCallbackException("Callback service convert data to json failed", e);
    }
  }

}
